==> ng2-bootstrap-1.0.7.jar: META-INF/resources/webjars/ng2-bootstrap/1.0.7/components/timepicker/timepicker.component.d.ts <==
import { OnInit } from 'angular2/core';
import { NgModel, ControlValueAccessor } from 'angular2/common';
export interface ITimepickerConfig {
    hourStep: number;
    minuteStep: number;
    showMeridian: boolean;
    meridians?: any[];
    readonlyInput: boolean;
    mousewheel: boolean;
    arrowkeys: boolean;
    showSpinners: boolean;
    min?: number;
    max?: number;
}
export declare const timepickerConfig: ITimepickerConfig;
export declare class Timepicker implements ControlValueAccessor, OnInit {
    cd: NgModel;
    private hourStep;
    private minuteStep;
    private readonlyInput;
    private mousewheel;
    private arrowkeys;
    private showSpinners;
    private min;
    private max;
    private meridians;
    private showMeridian;
    private _selected;
    private _showMeridian;
    private meridian;
    private hours;
    private minutes;
    private selected;
    private invalidHours;
    private invalidMinutes;
    constructor(cd: NgModel);
    ngOnInit(): void;
    writeValue(v: any): void;
    private refresh(type?);
    private updateTemplate(keyboardChange?);
    private getHoursFromTemplate();
    private getMinutesFromTemplate();
    private pad(value);
    private setupMousewheelEvents();
    private setupArrowkeyEvents();
    private setupInputEvents();
    private updateHours();
    private hoursOnBlur(event);
    private updateMinutes();
    private minutesOnBlur(event);
    private noIncrementHours();
    private noDecrementHours();
    private noIncrementMinutes();
    private noDecrementMinutes();
    private addMinutesToSelected(minutes);
    noToggleMeridian(): boolean;
    private incrementHours();
    private decrementHours();
    private incrementMinutes();
    private decrementMinutes();
    private toggleMeridian();
    onChange: (_: any) => void;
    onTouched: () => void;
    registerOnChange(fn: (_: any) => {}): void;
    registerOnTouched(fn: () => {}): void;
}

==> ng2-bootstrap-1.0.13.jar: META-INF/resources/webjars/ng2-bootstrap/1.0.13/components/timepicker/timepicker.component.d.ts <==
import { OnInit } from 'angular2/core';
import { NgModel, ControlValueAccessor } from 'angular2/common';
export interface ITimepickerConfig {
    hourStep: number;
    minuteStep: number;
    showMeridian: boolean;
    meridians?: any[];
    readonlyInput: boolean;
    mousewheel: boolean;
    arrowkeys: boolean;
    showSpinners: boolean;
    min?: number;
    max?: number;
}
export declare const timepickerConfig: ITimepickerConfig;
export declare class Timepicker implements ControlValueAccessor, OnInit {
    cd: NgModel;
    hourStep: number;
    minuteStep: number;
    readonlyInput: boolean;
    mousewheel: boolean;
    arrowkeys: boolean;
    showSpinners: boolean;
    min: Date;
    max: Date;
    meridians: Array<string>;
    showMeridian: boolean;
    private _selected;
    private _showMeridian;
    private meridian;
    private hours;
    private minutes;
    private selected;
    private invalidHours;
    private invalidMinutes;
    constructor(cd: NgModel);
    ngOnInit(): void;
    writeValue(v: any): void;
    onChange: any;
    onTouched: any;
    registerOnChange(fn: (_: any) => {}): void;
    registerOnTouched(fn: () => {}): void;
    protected updateHours(): void;
    protected hoursOnBlur(): void;
    protected updateMinutes(): void;
    protected minutesOnBlur(): void;
    protected incrementHours(): void;
    protected decrementHours(): void;
    protected incrementMinutes(): void;
    protected decrementMinutes(): void;
    protected toggleMeridian(): void;
    private refresh();
    private updateTemplate();
    private getHoursFromTemplate();
    private getMinutesFromTemplate();
    private pad(value);
    private noIncrementHours();
    private noDecrementHours();
    private noIncrementMinutes();
    private noDecrementMinutes();
    private addMinutesToSelected(minutes);
    private noToggleMeridian();
}
